@@ -9,7 +9,17 @@
 from pilas.actores import Actor
 
 class Ejes(Actor):
-    "Representa el eje de coordenadas tomado como sistema de referencia."
+    """Representa el eje de coordenadas tomado como sistema de referencia.
+
+    Este actor es útil para mostrar que la ventana
+    de pilas tiene una referencia, y que las posiciones
+    responden a este modelo.
+
+    Para crear el eje podrías ejecutar:
+
+        >>> eje = pilas.actore.Eje()
+
+    """
 
     def __init__(self, x=0, y=0):
         Actor.__init__(self, "ejes.png", x=x, y=y)
