@@ -17,7 +17,7 @@ except ImportError:
 import math
 
 class Fisica(object):
-    "Representa un simulador de mundo fisico, usando la biblioteca box2d."
+    """Representa un simulador de mundo fisico, usando la biblioteca box2d."""
     
     def __init__(self, area, gravedad=(0, -90)):
         self.area = area
@@ -67,9 +67,9 @@ class Fisica(object):
             self.constante_mouse.eliminar()
             self.constante_mouse = None
         
-    def actualizar(self):
+    def actualizar(self, velocidad=1.0):
         if self.mundo:
-            self.mundo.Step(1.0 / 20.0, 10, 8)
+            self.mundo.Step(velocidad / 20.0, 10, 8)
             self.i += 1
             self._procesar_figuras_a_eliminar()
 
@@ -99,7 +99,6 @@ class Fisica(object):
                     
                     for v in figura.vertices:
                         pt = box2d.b2Mul(xform, v)
-                        
                         vertices.append((pt.x, pt.y))
                         
                     lienzo.poligono(motor, vertices, color=colores.rojo, grosor=grosor, cerrado=True)
@@ -193,7 +192,11 @@ class Fisica(object):
         pilas.fisica.definir_gravedad(x, y)
 
 class Figura(object):
-    "Representa un figura que simula un cuerpo fisico."
+    """Representa un figura que simula un cuerpo fisico.
+    
+    Esta figura es abstracta, no está pensada para crear
+    objetos a partir de ella. Se usa como base para el resto
+    de las figuras cómo el Circulo o el Rectangulo simplemente."""
 
     def obtener_x(self):
         return self._cuerpo.position.x
@@ -246,8 +249,22 @@ class Figura(object):
     rotacion = property(obtener_rotacion, definir_rotacion, doc="define la rotacion.")
     
 class Circulo(Figura):
-    "Representa un cuerpo de circulo."
-    
+    """Representa un cuerpo de circulo.
+
+    Generalmente estas figuras se pueden construir independientes de un
+    actor, y luego asociar.
+
+    Por ejemplo, podríamos crear un círculo:
+
+        >>> circulo_dinamico = pilas.fisica.Circulo(10, 200, 50)
+
+    y luego tomar un actor cualquiera, y decirle que se comporte
+    cómo el circulo:
+
+        >>> mono = pilas.actores.Mono()
+        >>> mono.imitar(circulo_dinamico)
+    """
+
     def __init__(self, x, y, radio, dinamica=True, densidad=1.0, 
             restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
             fisica=None):
@@ -281,6 +298,16 @@ class Circulo(Figura):
         self._cuerpo = body
 
 class Rectangulo(Figura):
+    """Representa un rectángulo que puede colisionar con otras figuras.
+
+    Se puede crear un rectángulo independiente y luego asociarlo
+    a un actor de la siguiente forma:
+
+        >>> rect = pilas.fisica.Rectangulo(50, 90, True)
+        >>> actor = pilas.actores.Pingu()
+        >>> actor.imitar(rect)
+    """
+
     def __init__(self, x, y, ancho, alto, dinamica=True, densidad=1.0, 
             restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
             fisica=None):
@@ -315,6 +342,58 @@ class Rectangulo(Figura):
 
         self._cuerpo = body
 
+
+class Poligono(Figura):
+    """Representa un cuerpo poligonal.
+
+    El poligono necesita al menos tres puntos para dibujarse, y cada
+    uno de los puntos se tienen que ir dando en orden de las agujas
+    del relog.
+
+    Por ejemplo:
+
+        >>> pilas.fisica.Poligono([(100, 2), (-50, 0), (-100, 100.0)])
+        
+    """
+    
+    def __init__(self, puntos, dinamica=True, densidad=1.0, 
+            restitucion=0.56, friccion=10.5, amortiguacion=0.1, 
+            fisica=None):
+
+        if not fisica:
+            fisica = pilas.mundo.fisica
+            
+        bodyDef = box2d.b2BodyDef()
+        bodyDef.position=puntos[0]
+        bodyDef.linearDamping = amortiguacion
+        body = fisica.crear_cuerpo(bodyDef)
+
+        # Create the Body
+        if not dinamica:
+            densidad = 0
+
+        if len(puntos) < 3:
+            raise Exception("Tienes que definir al menos 3 puntos para tener un poligono")
+
+        # Add a shape to the Body
+        poligono_def = box2d.b2PolygonDef()
+        puntos.reverse()
+        poligono_def.setVertices(puntos)
+
+        poligono_def.density = densidad
+        poligono_def.restitution = restitucion
+        poligono_def.friction = friccion
+        #poligono_def.setVertices(puntos)
+        #poligono_def.vertexCount = len(puntos)
+
+        #for indice, punto in enumerate(puntos):
+        #    poligono_def.setVertex(indice, punto[0], punto[1])
+        #    #poligono_def.vertices[indice] = punto
+        
+        body.CreateShape(poligono_def)
+        body.SetMassFromShapes()
+        self._cuerpo = body
+
 class ConstanteDeMovimiento():
 
     def __init__(self, figura):
