@@ -20,7 +20,6 @@ except ImportError:
     print "No se encuentra soporte OpenGL en este equipo."
 
 
-import motor
 from pilas import imagenes
 from pilas import actores
 from pilas import eventos
@@ -31,6 +30,12 @@ from pilas import fps
 from pilas import simbolos
 from pilas import colores
 
+import motor
+
+# Permite cerrar el programa usando CTRL+C
+import signal                                                                                    
+signal.signal(signal.SIGINT, signal.SIG_DFL)
+
 
 class BaseActor(object):
     
@@ -82,7 +87,7 @@ class BaseActor(object):
     def set_espejado(self, espejado):        
         self._espejado = espejado
         
-class QtImagen(object):
+class Imagen(object):
 
     def __init__(self, ruta):
         self.ruta_original = ruta
@@ -130,7 +135,7 @@ class QtImagen(object):
         return "<Imagen del archivo '%s'>" %(nombre_imagen)
 
 
-class QtGrilla(QtImagen):
+class Grilla(Imagen):
 
     """Representa una grilla regular, que se utiliza en animaciones.
 
@@ -141,12 +146,12 @@ class QtGrilla(QtImagen):
     """
 
     def __init__(self, ruta, columnas=1, filas=1):
-        QtImagen.__init__(self, ruta)
+        Imagen.__init__(self, ruta)
         self.cantidad_de_cuadros = columnas * filas
         self.columnas = columnas
         self.filas = filas
-        self.cuadro_ancho = QtImagen.ancho(self) / columnas
-        self.cuadro_alto = QtImagen.alto(self) / filas
+        self.cuadro_ancho = Imagen.ancho(self) / columnas
+        self.cuadro_alto = Imagen.alto(self) / filas
         self.definir_cuadro(0)
 
     def ancho(self):
@@ -185,7 +190,7 @@ class QtGrilla(QtImagen):
     def dibujarse_sobre_una_pizarra(self, pizarra, x, y):
         pizarra.pintar_parte_de_imagen(self, self.dx, self.dy, self.cuadro_ancho, self.cuadro_alto, x, y)
 
-class QtTexto(QtImagen):
+class Texto(Imagen):
 
     def __init__(self, texto, magnitud, motor):
         self._ancho, self._alto = motor.obtener_area_de_texto(texto, magnitud)
@@ -211,7 +216,7 @@ class QtTexto(QtImagen):
         return self._alto
 
 
-class QtLienzo(QtImagen):
+class Lienzo(Imagen):
 
     def __init__(self):
         pass
@@ -282,7 +287,7 @@ class QtLienzo(QtImagen):
         motor.canvas.setPen(pen)
         motor.canvas.drawRect(x, y, ancho, alto)
 
-class QtSuperficie(QtImagen):
+class Superficie(Imagen):
 
     def __init__(self, ancho, alto):
         self._imagen = QtGui.QPixmap(ancho, alto)
@@ -377,7 +382,7 @@ class QtSuperficie(QtImagen):
     def limpiar(self):
         self._imagen.fill(QtGui.QColor(0, 0, 0, 0))
 
-class QtActor(BaseActor):
+class Actor(BaseActor):
 
     def __init__(self, imagen="sin_imagen.png", x=0, y=0):
 
@@ -392,7 +397,7 @@ class QtActor(BaseActor):
 
     def definir_imagen(self, imagen):
         # permite que varios actores usen la misma grilla.
-        if isinstance(imagen, QtGrilla):
+        if isinstance(imagen, Grilla):
             self.imagen = copy.copy(imagen)
         else:
             self.imagen = imagen
@@ -417,7 +422,7 @@ class QtActor(BaseActor):
                 self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
-class QtSonido:
+class Sonido:
 
     def __init__(self, ruta):
         import pygame
@@ -430,9 +435,8 @@ class QtSonido:
         # print "Usando pygame para reproducir sonido"
         self.sonido.play()
         
-class QtBase(motor.Motor):
-    
-    app = QtGui.QApplication([])
+
+class Base(motor.Motor):
     
     def __init__(self):
         motor.Motor.__init__(self)
@@ -455,14 +459,17 @@ class QtBase(motor.Motor):
         self.centrar_ventana()
         self.setWindowTitle(self.titulo)
 
+        self.mostrar_ventana(pantalla_completa)
+
+        # Activa la invocacion al evento timerEvent.
+        self.startTimer(1000/60.0)
+
+    def mostrar_ventana(self, pantalla_completa):
         if pantalla_completa:
             self.showFullScreen()
         else:
             self.show()
 
-        # Activa la invocacion al evento timerEvent.
-        self.startTimer(1000/60.0)
-
     def pantalla_completa(self):
         self.showFullScreen()
 
@@ -496,13 +503,13 @@ class QtBase(motor.Motor):
                     (escritorio.height()-self.alto)/2, self.ancho, self.alto)
 
     def obtener_actor(self, imagen, x, y):
-        return QtActor(imagen, x, y)
+        return Actor(imagen, x, y)
 
     def obtener_texto(self, texto, magnitud):
-        return QtTexto(texto, magnitud, self)
+        return Texto(texto, magnitud, self)
 
     def obtener_grilla(self, ruta, columnas, filas):
-        return QtGrilla(ruta, columnas, filas)
+        return Grilla(ruta, columnas, filas)
 
     def actualizar_pantalla(self):
         self.ventana.update()
@@ -515,16 +522,16 @@ class QtBase(motor.Motor):
         return (self.camara_x, self.camara_y)
 
     def cargar_sonido(self, ruta):
-        return QtSonido(ruta)
+        return Sonido(ruta)
 
     def cargar_imagen(self, ruta):
-        return QtImagen(ruta)
+        return Imagen(ruta)
 
     def obtener_lienzo(self):
-        return QtLienzo()
+        return Lienzo()
 
     def obtener_superficie(self, ancho, alto):
-        return QtSuperficie(ancho, alto)
+        return Superficie(ancho, alto)
 
     def ejecutar_bucle_principal(self, mundo, ignorar_errores):
         sys.exit(self.app.exec_())
@@ -558,12 +565,10 @@ class QtBase(motor.Motor):
         self.canvas.end()
 
     def timerEvent(self, event):
-
-        if not self.pausa_habilitada:
-            try:
-                self.realizar_actualizacion_logica()
-            except Exception as e:
-                print e
+        try:
+            self.realizar_actualizacion_logica()
+        except Exception as e:
+            print e.__class__.__name__ + ": " + str(e)
 
         # Invoca el dibujado de la pantalla.
         self.update()
@@ -577,6 +582,9 @@ class QtBase(motor.Motor):
                 for actor in actores.todos:
                     actor.pre_actualizar()
                     actor.actualizar()
+            else:
+                eventos.actualizar_pausado.send("Qt::timerEvent")
+
 
     def resizeEvent(self, event):
         self.ancho = event.size().width()
@@ -608,9 +616,9 @@ class QtBase(motor.Motor):
 
         if event.key() == QtCore.Qt.Key_Escape:
             eventos.pulsa_tecla_escape.send("Qt::keyPressEvent")
-        if event.key() == QtCore.Qt.Key_P:
+        if event.key() == QtCore.Qt.Key_P and event.modifiers() == QtCore.Qt.AltModifier:
             self.alternar_pausa()
-        if event.key() == QtCore.Qt.Key_F:
+        if event.key() == QtCore.Qt.Key_F and event.modifiers() == QtCore.Qt.AltModifier:
             self.alternar_pantalla_completa()
 
         eventos.pulsa_tecla.send("Qt::keyPressEvent", codigo=codigo_de_tecla, texto=event.text())
@@ -639,6 +647,32 @@ class QtBase(motor.Motor):
             QtCore.Qt.Key_F10: simbolos.F10,
             QtCore.Qt.Key_F11: simbolos.F11,
             QtCore.Qt.Key_F12: simbolos.F12,
+            QtCore.Qt.Key_A: simbolos.a,
+            QtCore.Qt.Key_B: simbolos.b,
+            QtCore.Qt.Key_C: simbolos.c,
+            QtCore.Qt.Key_D: simbolos.d,
+            QtCore.Qt.Key_E: simbolos.e,
+            QtCore.Qt.Key_F: simbolos.f,
+            QtCore.Qt.Key_G: simbolos.g,
+            QtCore.Qt.Key_H: simbolos.h,
+            QtCore.Qt.Key_I: simbolos.i,
+            QtCore.Qt.Key_J: simbolos.j,
+            QtCore.Qt.Key_K: simbolos.k,
+            QtCore.Qt.Key_L: simbolos.l,
+            QtCore.Qt.Key_M: simbolos.m,
+            QtCore.Qt.Key_N: simbolos.n,
+            QtCore.Qt.Key_O: simbolos.o,
+            QtCore.Qt.Key_P: simbolos.p,
+            QtCore.Qt.Key_Q: simbolos.q,
+            QtCore.Qt.Key_R: simbolos.r,
+            QtCore.Qt.Key_S: simbolos.s,
+            QtCore.Qt.Key_T: simbolos.t,
+            QtCore.Qt.Key_U: simbolos.u,
+            QtCore.Qt.Key_V: simbolos.v,
+            QtCore.Qt.Key_W: simbolos.w,
+            QtCore.Qt.Key_X: simbolos.x,
+            QtCore.Qt.Key_Y: simbolos.y,
+            QtCore.Qt.Key_Z: simbolos.z,
         }
 
         if teclas.has_key(tecla_qt):
@@ -679,25 +713,87 @@ class QtBase(motor.Motor):
         nuevo_cursor = QtGui.QCursor(bitmap, bitmap)
         self.setCursor(QtGui.QCursor(nuevo_cursor))
 
-class Qt(QtBase, QWidget):
+    def terminar(self):
+        self.close()
 
-    def __init__(self):
+class Widget(Base, QWidget):
+
+    def __init__(self, app):
+        self.nombre = 'qt'
+        self.app = app
         QWidget.__init__(self)
-        QtBase.__init__(self)
+        Base.__init__(self)
 
-class QtGL(QtBase, QGLWidget):
 
-    def __init__(self):
+
+class WidgetGL(Base, QGLWidget):
+
+    def __init__(self, app):
+        self.nombre = 'qtgl'
+        self.app = app
+
         if not QGLWidget:
             print "Lo siento, OpenGL no esta disponible..."
 
         QGLWidget.__init__(self)
-        QtBase.__init__(self)
+        Base.__init__(self)
         self._pintar_fondo_negro()
 
     def _pintar_fondo_negro(self):
         color = QtGui.QColor(99, 0, 0)
         self.setStyleSheet("QWidget { background-color: %s }" % color.name())
 
-if QGLWidget == object:
-    QtGL = Qt
+class WidgetSugar(Widget):
+
+    def __init__(self):
+        Widget.__init__(self, None)
+        self.nombre = 'qtsugar'
+
+    def ejecutar_bucle_principal(self, mundo, ignorar_errores):
+        pass
+
+    def mostrar_ventana(self, pantalla_completa):
+        pass
+
+class WidgetSugarGL(WidgetGL):
+
+    def __init__(self):
+        WidgetGL.__init__(self, None)
+        self.nombre = 'qtsugargl'
+
+    def ejecutar_bucle_principal(self, mundo, ignorar_errores):
+        pass
+
+    def mostrar_ventana(self, pantalla_completa):
+        pass
+
+class Motor(object):
+    """Representa la ventana principal de pilas.
+    
+    Esta clase construirá el objeto apuntado por el atributo
+    ``pilas.motor``, asi que será el representante de todas
+    las funcionalidades multimedia.
+    
+    Internamente, este motor, tratará de usar OpenGl para acelerar
+    el dibujado en pantalla si la tarjeta de video lo soporta.
+    """
+
+    def __init__(self, usar_motor):
+        if usar_motor == 'qtgl':
+            app = QtGui.QApplication([])
+
+            if QGLWidget == object:
+                self.widget = Widget(app)
+            else:
+                self.widget = WidgetGL(app)
+        elif usar_motor == 'qt':
+            app = QtGui.QApplication([])
+            self.widget = Widget(app)
+        elif usar_motor == 'qtsugar':
+            self.widget = WidgetSugar()
+        elif usar_motor == 'qtsugargl':
+            self.widget = WidgetSugarGL()
+
+    def __getattr__(self, method):
+        "Delega todos los pedidos de funcionalidad al widget interno."
+        return getattr(self.widget, method)
